# Mailstro Client for Ruby

A quick and easy way to send emails from your ruby application.

## Installation

1.  Add the `mailstro` gem to your `Gemfile`

    ```ruby
    gem "mailstro"
    ```

2.  Install the gem

    ```shell
    bundle install
    ```

3.  Configure the mailstro module with your API key.

    In rails apps, put this code to a new file at `config/initializers/mailstro.rb`

    ```ruby
    Mailstro.configure do |config|
      config.api_key = "YOUR_API_KEY_HERE"
    end
    ```

    By default, mailstro operates in test mode. This ensures accidental emails are not sent
    in development or staging environments.

    In rails apps, put this code to a new file at `config/environments/production.rb`

    ```ruby
    # Enable production mode, and start sending real emails.
    Mailstro.configure do |config|
      config.enabled = true
    end
    ```

## Usage

Sending a basic email.

```ruby
Mailstro.deliver(:welcome,
  :to => 'shanon@mailstroapp.com',
  :data => {
    :coupon_code => 'THANKS01'
  }
)
```

## RSpec

Require the mailstro spec helper to automatically enable test mode.

```ruby
require 'mailsto/rspec'
```

Verify emails are being sent with simple matchers.

```ruby
Mailstro.deliver(:welcome,
  :to => 'shanon@mailstroapp.com'
)

Mailstro.should have_delivered(:welcome,
  :to => 'shanon@mailstroapp.com'
)
```

## Contributing

1. Fork it
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create new Pull Request
